import requests
from bs4 import BeautifulSoup
from geojson import Feature, FeatureCollection, Point


def get_incidents():
    """
    Get active incidents data from InciWeb.

    Returns GeoJson FeatureCollection.
    """
    url = "https://inciweb.nwcg.gov/feeds/maps/placemarks.kml"
    r = requests.get(url)
    soup = BeautifulSoup(r.content, "xml")
    folder_list = soup.find_all("Folder")
    feature_list = []
    for folder in folder_list:
        d = dict(name=folder.find("name").text, url=folder.find("Placemark").a["href"])
        coords = folder.find("Point").find("coordinates").text.split(",")
        p = Point(map(_safe_float, coords))
        f = Feature(geometry=p, properties=d)
        feature_list.append(f)

    return FeatureCollection(feature_list)


def _safe_float(v):
    v = v.strip()
    # Fix the weird points that end with an extra "."
    v = ".".join(v.split(".")[:2])
    return float(v)



import os

from setuptools import setup


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as f:
        return f.read()


def version_scheme(version):
    """
    Version scheme hack for setuptools_scm.

    Appears to be necessary to due to the bug documented here: https://github.com/pypa/setuptools_scm/issues/342

    If that issue is resolved, this method can be removed.
    """
    import time

    from setuptools_scm.version import guess_next_version

    if version.exact:
        return version.format_with("{tag}")
    else:
        _super_value = version.format_next_version(guess_next_version)
        now = int(time.time())
        return _super_value + str(now)


def local_version(version):
    """
    Local version scheme hack for setuptools_scm.

    Appears to be necessary to due to the bug documented here: https://github.com/pypa/setuptools_scm/issues/342

    If that issue is resolved, this method can be removed.
    """
    return ""


setup(
    name="inciweb-wildfires",
    description="Download wildfire incidents data from InciWeb",
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    author="Ben Welsh",
    author_email="b@palewi.re",
    url="http://www.github.com/datadesk/inciweb-wildfires",
    license="MIT",
    packages=("inciweb_wildfires",),
    install_requires=["requests", "geojson", "click", "bs4", "lxml"],
    entry_points="""
        [console_scripts]
        inciwebwildfires=inciweb_wildfires.cli:cmd
        inciweb-wildfires=inciweb_wildfires.cli:cmd
    """,
    use_scm_version={"version_scheme": version_scheme, "local_scheme": local_version},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
    ],
    project_urls={
        "Maintainer": "https://github.com/datadesk",
        "Source": "https://github.com/datadesk/inciweb-wildfires",
        "Tracker": "https://github.com/datadesk/inciweb-wildfires/issues",
    },
)



import unittest

from inciweb_wildfires import get_incidents


class InciwebWildfiresUnitTest(unittest.TestCase):
    def test_inciweb(self):
        get_incidents()


if __name__ == "__main__":
    unittest.main()
